@@ -18,7 +18,7 @@ class CSVDataset(Dataset):
         train (bool): Whether the dataset is for training or not. Defaults to True.
         rmNA (bool): Whether to remove rows with NA values or not. Defaults to True.
         dropId (bool): Whether to drop the "id" column or not. Defaults to False.
-        **desc: Additional keyword arguments.
+        **desc (Any): Additional keyword arguments.
 
     Attributes:
         data (Tensor): The data features.
@@ -33,7 +33,6 @@ class CSVDataset(Dataset):
             batch_size = 5
             # Create DataLoader
             dataloader = DataLoader(dataset, batch_size=batch_size, shuffle=False)
-
             # Iterate over the data in the DataLoader
             for batch in dataloader:
                 inputs, targets = batch
